# Changelog

<!--next-version-placeholder-->

## v2.7.0 (2025-03-04)



## v2.6.0 (2024-06-18)



## v2.5.0 (2024-06-17)



## v2.4.10 (2023-12-01)

### Other

* `rabbitmq`: Don't Keep Unlimited Dry Channels ([#116](https://github.com/Observation-Management-Service/MQClient/issues/116)) ([`583a4ee`](https://github.com/Observation-Management-Service/MQClient/commit/583a4eefe2b70b4a505c0619dca7d0707f0e065f))

## v2.4.9 (2023-11-01)

### Other

* Use `WIPACrepo/wipac-dev-py-setup-action@v2.8` ([#115](https://github.com/Observation-Management-Service/MQClient/issues/115)) ([`b274e2c`](https://github.com/Observation-Management-Service/MQClient/commit/b274e2c931673142623b0333cb08f405d23dbb02))

## v2.4.8 (2023-11-01)

### Other

* Use `WIPACrepo/wipac-dev-py-setup-action@v2.8` ([`3ce2a6e`](https://github.com/Observation-Management-Service/MQClient/commit/3ce2a6ef040a801cbd22a864104fe72a5b34afff))

## v2.4.7 (2023-10-03)

### Other

* Use `WIPACrepo/wipac-dev-py-setup-action@v2.6` ([#113](https://github.com/Observation-Management-Service/MQClient/issues/113)) ([`0de8785`](https://github.com/Observation-Management-Service/MQClient/commit/0de87851c83889fcb74639dd1a89cf0940d01930))

## v2.4.6 (2023-09-13)

### Other

* Allow Reentering `ManualQueueSubResource.iter_messages()` ([#112](https://github.com/Observation-Management-Service/MQClient/issues/112)) ([`b82b81e`](https://github.com/Observation-Management-Service/MQClient/commit/b82b81ecf72dd4a9cfc0462d46e476e0094191e4))

## v2.4.5 (2023-09-13)

### Other

* Update Rabbitmq Multi-Handling ([#111](https://github.com/Observation-Management-Service/MQClient/issues/111)) ([`93da9f7`](https://github.com/Observation-Management-Service/MQClient/commit/93da9f7233cf2630cf9adb2ede6b6c072e1195bc))

## v2.4.4 (2023-08-23)

### Other

* `ManualQueueSubResource` Tracking Fix ([#110](https://github.com/Observation-Management-Service/MQClient/issues/110)) ([`5bc272c`](https://github.com/Observation-Management-Service/MQClient/commit/5bc272cce82e00cc1ac8fc9939d37d2a0f62dd59))

## v2.4.3 (2023-07-28)

### Other

* Exception Handling Patches Pt-2 ([`43e7d58`](https://github.com/Observation-Management-Service/MQClient/commit/43e7d580be8cd29815bd6ed83a824543b4fb429a))

## v2.4.2 (2023-07-27)

### Other

* Okay to Close an Already Closed Connection ([#109](https://github.com/Observation-Management-Service/MQClient/issues/109)) ([`70c99a2`](https://github.com/Observation-Management-Service/MQClient/commit/70c99a229dfb36b8c9cca40803863b4350c10f2c))

## v2.4.1 (2023-07-27)

### Other

* Exception Handling Patches ([#108](https://github.com/Observation-Management-Service/MQClient/issues/108)) ([`72c4ebf`](https://github.com/Observation-Management-Service/MQClient/commit/72c4ebffc7c9a458d037a0b1609e8c68261a1bdc))

## v2.4.0 (2023-07-27)



## v2.3.4 (2023-07-25)

### Other

* Bump `wipac-dev-py-setup-action` & `wipac-dev-mypy-action` ([#105](https://github.com/Observation-Management-Service/MQClient/issues/105)) ([`1e28c48`](https://github.com/Observation-Management-Service/MQClient/commit/1e28c48a00e0cce0680d2ec8c572cd335e400c0b))

## v2.3.3 (2023-07-25)

### Other

* RabbitMQ Prefetch Redux ([#106](https://github.com/Observation-Management-Service/MQClient/issues/106)) ([`e0cb207`](https://github.com/Observation-Management-Service/MQClient/commit/e0cb207ff2219cc4ecb9205500295d4a9a6491b2))

## v2.3.2 (2023-07-17)

### Other

* Prefetch Updates: `open_sub_manual_acking()` ([#104](https://github.com/Observation-Management-Service/MQClient/issues/104)) ([`9ccf889`](https://github.com/Observation-Management-Service/MQClient/commit/9ccf8899de5a6e3bdf04b4bd41d1303c33e1ed48))

## v2.3.1 (2023-07-13)

### Other

* Prefetch Updates Follow-up ([#103](https://github.com/Observation-Management-Service/MQClient/issues/103)) ([`11ec98b`](https://github.com/Observation-Management-Service/MQClient/commit/11ec98b7c6f91fd2d04ae4ceafa46dd628f2193b))

## v2.3.0 (2023-07-11)



## v2.2.0 (2023-07-11)



## v2.1.1 (2023-07-06)

### Other

* Bump/Pin Dependencies ([#100](https://github.com/Observation-Management-Service/MQClient/issues/100)) ([`5f8df64`](https://github.com/Observation-Management-Service/MQClient/commit/5f8df64de4bfd86eb2e7c93233b24e8a2d9620b2))

## v2.1.0 (2023-04-25)


## v2.0.0 (2023-04-21)
### Breaking
* Co-authored-by: github-actions <github-actions@github.com> ([`b4dd082`](https://github.com/Observation-Management-Service/MQClient/commit/b4dd08298e27a5dbdfb311abe9cfed5b7abf3559))

## v1.2.0 (2023-04-05)


## v1.1.0 (2023-04-03)


## v1.0.6 (2023-02-28)
### Other
* Fix RabbitMQ `open_sub_one()` Timeout ([#87](https://github.com/Observation-Management-Service/MQClient/issues/87)) ([`062dd54`](https://github.com/Observation-Management-Service/MQClient/commit/062dd54e2b447fd7a84707df49eaf68643295c7b))

## v1.0.5 (2023-02-21)
### Other
* RabbitMQ Username via URL ([#85](https://github.com/Observation-Management-Service/MQClient/issues/85)) ([`98ad338`](https://github.com/Observation-Management-Service/MQClient/commit/98ad3389cf877de006ddf2460941e4b5fb136aa0))

## v1.0.4 (2023-02-17)
### Other
* CI Updates ([#83](https://github.com/Observation-Management-Service/MQClient/issues/83)) ([`e38ddda`](https://github.com/Observation-Management-Service/MQClient/commit/e38dddaf605617da67e8b27629560b3fdfc91eae))

## v1.0.3 (2023-02-17)
### Other
* Add CodeQL workflow for GitHub code scanning ([#59](https://github.com/Observation-Management-Service/MQClient/issues/59)) ([`fe88926`](https://github.com/Observation-Management-Service/MQClient/commit/fe889268c3dfbb6d59ff931dc27bd53faf610936))

## v1.0.2 (2023-02-15)
### Other
* `RABBITMQ_HEARTBEAT` Fix ([#82](https://github.com/Observation-Management-Service/MQClient/issues/82)) ([`3e6d9d9`](https://github.com/Observation-Management-Service/MQClient/commit/3e6d9d997deacb4457505ceda4c38a5a8fcc7311))

## v1.0.1 (2023-02-15)
### Other
* RabbitMQ Connection Fixes ([#81](https://github.com/Observation-Management-Service/MQClient/issues/81)) ([`0553141`](https://github.com/Observation-Management-Service/MQClient/commit/05531417e714512d59cfda0d8e1609a83de81847))

## v1.0.0 (2023-02-14)
### Breaking
* Co-authored-by: github-actions <github-actions@github.com> ([`d6fee3b`](https://github.com/Observation-Management-Service/MQClient/commit/d6fee3b0f6c22636d90af3ccf0fcda7d8f74d9e0))

## v0.7.1 (2023-02-14)


## v0.7.0 (2023-02-14)
### Feature
* RabbitMQ Auth ([#75](https://github.com/WIPACrepo/MQClient/issues/75)) ([`3626566`](https://github.com/WIPACrepo/MQClient/commit/36265663f74d0984562a57ba27cd681b06bd13f5))

## v0.6.8 (2022-12-05)


## v0.6.7 (2022-11-17)


## v0.6.6 (2022-11-17)


## v0.6.5 (2022-11-17)


## v0.6.4 (2022-11-15)


## v0.6.3 (2022-10-07)


## v0.6.2 (2022-10-04)


## v0.6.1 (2022-09-30)


## v0.6.0 (2022-09-28)
### Feature
* Merge In Child Repos ([#50](https://github.com/WIPACrepo/MQClient/issues/50)) ([`59c6480`](https://github.com/WIPACrepo/MQClient/commit/59c648066342c5c2b75c03f4fe3254d87fed3bf1))

## v0.5.1 (2022-08-05)


## v0.5.0 (2022-05-13)
### Feature
* Type Hint Patch & Package-Specific Logger ([#45](https://github.com/WIPACrepo/MQClient/issues/45)) ([`f11148b`](https://github.com/WIPACrepo/MQClient/commit/f11148b41da3b305b79c6587cebb3b97012d246b))

## v0.4.2 (2022-03-23)


## v0.4.1 (2022-03-22)


## v0.4.0 (2022-03-21)
### Feature
* Updates for PyPI Publish ([#40](https://github.com/WIPACrepo/MQClient/issues/40)) ([`f8758a9`](https://github.com/WIPACrepo/MQClient/commit/f8758a9ce90bd203a4042b4137ca1919f16f6d03))

## v0.3.0 (2022-02-02)
### Feature
* Rename Public-Facing API Methods ([#36](https://github.com/WIPACrepo/MQClient/issues/36)) ([`8b26b29`](https://github.com/WIPACrepo/MQClient/commit/8b26b29f92b3360f68bb382856fa3e085d0d71eb))

## v0.2.4 (2022-02-02)


## v0.2.3 (2022-01-26)


## v0.2.2 (2022-01-25)


## v0.2.1 (2022-01-19)


## v0.2.0 (2022-01-12)
### Feature
* Convert to Async-Await ([#28](https://github.com/WIPACrepo/MQClient/issues/28)) ([`a5d1808`](https://github.com/WIPACrepo/MQClient/commit/a5d1808dd29fbd9c6f5705f19f3aebc82af9cee4))

## v0.1.1 (2021-11-08)


## v0.1.0 (2021-11-05)
### Feature
* WIPAC Telemetry Compatible ([#23](https://github.com/WIPACrepo/MQClient/issues/23)) ([`ae5a928`](https://github.com/WIPACrepo/MQClient/commit/ae5a9286a8108cb767a458409f035c2927ad1fb0))

## v0.0.12 (2021-09-13)


## v0.0.11 (2021-08-18)


## v0.0.10 (2021-08-16)


## v0.0.9 (2021-07-22)


## v0.0.8 (2021-07-22)


## v0.0.7 (2021-07-21)


## v0.0.6 (2021-07-21)


## v0.0.5 (2021-07-20)


## v0.0.4 (2021-06-08)


## v0.0.3 (2021-04-20)


## v0.0.2 (2021-03-25)

